@@ -127,6 +127,7 @@ BBSListViewBase::BBSListViewBase( const std::string& url,const std::string& arg1
     : SKELETON::View( url ),
       m_treeview( url, DNDTARGET_FAVORITE, m_columns, true, CONFIG::get_fontname( FONT_BBS ), COLOR_CHAR_BBS, COLOR_BACK_BBS, COLOR_BACK_BBS_EVEN ),
       m_ready_tree( false ),
+      m_clicked( false ), 
       m_jump_y( -1 ),
       m_search_invert( false ),
       m_open_only_onedir( false ),
@@ -501,6 +502,8 @@ const bool BBSListViewBase::set_command( const std::string& command, const std::
     else if( command == "toggle_boardicon" ) toggle_boardicon( arg1 );
     else if( command == "replace_thread" ) replace_thread( arg1, arg2 );
 
+    else if( command == "hide_popup" ) m_treeview.hide_popup();
+
     else if( command == "check_update_root" ) check_update_root( false );
     else if( command == "check_update_open_root" ) check_update_root( true );
     else if( command == "cancel_check_update" ) stop();
@@ -573,6 +576,23 @@ void BBSListViewBase::set_fgcolor_of_comment( const Gtk::TreeModel::Children& ch
 //
 // 再描画
 //
+void BBSListViewBase::redraw_view()
+{
+    // 起動中とシャットダウン中は処理しない
+    if( SESSION::is_booting() ) return;
+    if( SESSION::is_quitting() ) return;
+
+#ifdef _DEBUG
+    std::cout << "BBSListViewBase::ViewBase::redraw_view " << get_url() << std::endl;
+#endif
+
+    m_treeview.redraw_view();
+}
+
+
+//
+// 色やフォントなどの変更
+//
 void BBSListViewBase::relayout()
 {
     m_treeview.init_color( COLOR_CHAR_BBS, COLOR_BACK_BBS, COLOR_BACK_BBS_EVEN );
@@ -606,7 +626,7 @@ void BBSListViewBase::focus_out()
     SKELETON::View::focus_out();
 
     m_treeview.hide_tooltip();
-    m_treeview.delete_popup();
+    m_treeview.hide_popup();
 }
 
 
@@ -879,6 +899,11 @@ const bool BBSListViewBase::operate_view( const int control )
             redo();
             break;
 
+            // URLを開くダイアログを表示
+        case CONTROL::OpenURL:
+            CORE::core_set_command( "show_openurl_diag" );
+            break;
+
         default:
             return false;
     }
@@ -1036,6 +1061,8 @@ void BBSListViewBase::copy_treestore( Glib::RefPtr< Gtk::TreeStore >& store )
 //
 bool BBSListViewBase::slot_button_press( GdkEventButton* event )
 {
+    m_clicked = true;
+
     // マウスジェスチャ
     get_control().MG_start( event );
 
@@ -1044,8 +1071,8 @@ bool BBSListViewBase::slot_button_press( GdkEventButton* event )
 
     // ダブルクリック
     // button_release_eventでは event->type に必ず GDK_BUTTON_RELEASE が入る
-    m_dblclick = false;
-    if( event->type == GDK_2BUTTON_PRESS ) m_dblclick = true; 
+    m_dblclicked = false;
+    if( event->type == GDK_2BUTTON_PRESS ) m_dblclicked = true; 
 
     // 親ウィンドウがメインウィンドウならフォーカスを移す
     if( ! get_parent_win() ) BBSLIST::get_admin()->set_command( "switch_admin" );
@@ -1059,6 +1086,9 @@ bool BBSListViewBase::slot_button_press( GdkEventButton* event )
 //
 bool BBSListViewBase::slot_button_release( GdkEventButton* event )
 {
+    if( ! m_clicked ) return true;
+    m_clicked = false;
+
     /// マウスジェスチャ
     int mg = get_control().MG_end( event );
 
@@ -1077,7 +1107,7 @@ bool BBSListViewBase::slot_button_release( GdkEventButton* event )
 
     // ダブルクリックの処理のため一時的にtypeを切替える
     GdkEventType type_copy = event->type;
-    if( m_dblclick ) event->type = GDK_2BUTTON_PRESS;
+    if( m_dblclicked ) event->type = GDK_2BUTTON_PRESS;
 
     // 行を開く
     if( get_control().button_alloted( event, CONTROL::OpenBoardButton ) ) operate_view( CONTROL::OpenBoardButton );
@@ -1123,6 +1153,8 @@ bool BBSListViewBase::slot_motion_notify( GdkEventMotion* event )
         Glib::ustring url = row[ m_columns.m_url ];
         int type = row[ m_columns.m_type ];
 
+        m_treeview.reset_pre_popupurl( url );
+
         // 画像ポップアップ
         if( type == TYPE_IMAGE ){
 
@@ -1132,18 +1164,17 @@ bool BBSListViewBase::slot_motion_notify( GdkEventMotion* event )
 
                 if( m_treeview.pre_popup_url() != url ){
 
-                    m_treeview.delete_popup();
                     SKELETON::View* view = CORE::ViewFactory( CORE::VIEW_IMAGEPOPUP,  url );
                     m_treeview.show_popup( url, view );
                 }
             }
-            else m_treeview.delete_popup();
+            else m_treeview.hide_popup();
         }
 
         // ツールチップ
         else{
 
-            m_treeview.delete_popup();
+            m_treeview.hide_popup();
 
             Gdk::Rectangle rect;
             m_treeview.get_cell_area( path, *column, rect );
@@ -1153,7 +1184,7 @@ bool BBSListViewBase::slot_motion_notify( GdkEventMotion* event )
     }
     else{
         m_treeview.hide_tooltip();
-        m_treeview.delete_popup();
+        m_treeview.hide_popup();
     }
     
     return true;
@@ -1164,7 +1195,7 @@ bool BBSListViewBase::slot_motion_notify( GdkEventMotion* event )
 //
 // キーを押した
 //
-bool BBSListViewBase::slot_key_press( GdkEventKey* event )
+const bool BBSListViewBase::slot_key_press( GdkEventKey* event )
 {
     // 行の名前を編集中なら何もしない
     if( m_treeview.is_renaming_row() ) return false;
@@ -1468,6 +1499,7 @@ void BBSListViewBase::add_newetcboard( const bool move, // true なら編集モ
             CORE::DATA_INFO_LIST list_info;
             CORE::DATA_INFO info;
             info.type = TYPE_BOARD;
+            info.parent = NULL;
             info.url = url;
             info.name = name;
             info.data = std::string();
@@ -1823,7 +1855,7 @@ void BBSListViewBase::slot_row_exp( const Gtk::TreeModel::iterator&, const Gtk::
     }
 
     m_treeview.set_cursor( path );
-    m_treeview.scroll_to_row( path, 0.1 );
+    if( CONFIG::get_scroll_tree() ) m_treeview.scroll_to_row( path, 0.1 );
     show_status();
 }
 
@@ -2262,9 +2294,16 @@ void BBSListViewBase::update_urls()
     if( m_treestore->children().empty() ) return; 
    
 #ifdef _DEBUG
-    std::cout << "BBSListViewBase::update_urls()\n";
+    std::cout << "BBSListViewBase::update_urls " << get_url() << std::endl;
 #endif
 
+    bool updated = false;
+
+    // 移転情報の保存( Root::save_movetable() )を無効にする。
+    // 無効にしないと DBTREE::url_boardbase() -> Root::get_board() 経由で
+    // 繰り返し Root::save_movetable() が実行されてJDが固まったようになる
+    DBTREE::set_enable_save_movetable( false );
+
     m_set_board.clear();
     m_set_thread.clear();
     
@@ -2289,11 +2328,15 @@ void BBSListViewBase::update_urls()
                 case TYPE_BOARD_UPDATE:
 
                     url_new = DBTREE::url_boardbase( url );
-                    row[ m_columns.m_url ] = url_new;
-                    m_set_board.insert( url_new );
+                    if( url != url_new ){
+                        updated = true;
+                        row[ m_columns.m_url ] = url_new;
 #ifdef _DEBUG
-                    std::cout << url << " -> " << url_new << std::endl;
+                        std::cout << url << " -> " << url_new << std::endl;
 #endif
+                    }
+
+                    m_set_board.insert( url_new );
                     path.next();
                     break;
 
@@ -2302,11 +2345,15 @@ void BBSListViewBase::update_urls()
                 case TYPE_THREAD_OLD:
 
                     url_new = DBTREE::url_dat( url );
-                    row[ m_columns.m_url ] = url_new;
-                    m_set_thread.insert( url_new );
+                    if( url != url_new ){
+                        updated = true;
+                        row[ m_columns.m_url ] = url_new;
 #ifdef _DEBUG
-                    std::cout << url << " -> " << url_new << std::endl;
+                        std::cout << url << " -> " << url_new << std::endl;
 #endif
+                    }
+
+                    m_set_thread.insert( url_new );
                     path.next();
                     break;
 
@@ -2326,6 +2373,13 @@ void BBSListViewBase::update_urls()
             else break;
         }
     }
+
+    DBTREE::set_enable_save_movetable( true );
+
+    if( updated ){
+        save_xml( false );
+        DBTREE::save_movetable();
+    }
 }
 
 
@@ -2732,10 +2786,11 @@ void BBSListViewBase::append_item()
 
     // 挿入先ダイアログ内で編集を行うとバッファがクリアされてしまうので
     // バックアップを取っておく
-    const CORE::DATA_INFO_LIST list_info_bkup = CORE::SBUF_list_info();
+    CORE::DATA_INFO_LIST list_info_bkup = CORE::SBUF_list_info();
 
     // 挿入先ダイアログ表示
-    SelectListDialog diag( get_url(), get_treestore() );
+    Gtk::Window* parent = ( *list_info_bkup.begin() ).parent;
+    SelectListDialog diag( parent, get_url(), get_treestore() );
     if( diag.run() != Gtk::RESPONSE_OK ) return;
 
     bool before = false;
@@ -2743,6 +2798,7 @@ void BBSListViewBase::append_item()
     const bool scroll = true;
 
     const std::string path_str = diag.get_path();
+    if( list_info_bkup.size() == 1 && ! diag.get_name().empty() ) ( *list_info_bkup.begin() ).name = diag.get_name();
 
     // 先頭
     if( path_str == "-1" ){
@@ -2839,6 +2895,7 @@ void BBSListViewBase::get_history( CORE::DATA_INFO_LIST& info_list )
         Gtk::TreeModel::Row row = *it;
 
         info.type = row2type( row );
+        info.parent = NULL;
         info.url = row2url( row );
         info.name = row2name( row );
 
