@@ -75,7 +75,8 @@ namespace CONFIG
         std::string x_2ch_ua;
 
         // ローダのバッファサイズ
-        int loader_bufsize;
+        int loader_bufsize; // 一般
+        int loader_bufsize_board; // スレ一覧用
 
         // ローダのタイムアウト値
         int loader_timeout;
@@ -145,6 +146,9 @@ namespace CONFIG
         // 画像の最大サイズ(Mピクセル)
         int max_img_pixel;
 
+        // 画像のメモリキャッシュ枚数
+        int imgcache_size;
+
         // JD ホームページのアドレス
         std::string url_jdhp;
 
@@ -184,9 +188,15 @@ namespace CONFIG
         // ツリービューでgtkrcの設定を使用するか
         bool use_tree_gtkrc;
 
+        // スレビューの選択色でgtkrcの設定を使用するか
+        bool use_select_gtkrc;
+
         // ツリービューの行間スペース
         int tree_ypad;
 
+        // カテゴリを開いたときにツリービューをスクロールする
+        bool scroll_tree;
+
         // 各ビューと枠との間の余白
         int view_margin;
 
@@ -202,6 +212,12 @@ namespace CONFIG
         // スレ一覧でdeleteを押したときに確認ダイアログを表示する
         bool show_deldiag;
 
+        // スレ一覧をロードする前にキャッシュにある一覧を表示
+        bool show_cached_board;
+
+        // スレ一覧でお知らせスレ(924)のアイコンを表示する
+        bool show_924;
+
         // ツリービューのスクロール量(マウスホイール上下・行数)
         int tree_scroll_size;
 
@@ -253,6 +269,9 @@ namespace CONFIG
         // 非アクティブ時に書き込みビューを折りたたむ
         bool fold_message;
 
+        // 書き込み欄の日本語のON/OFF状態を保存
+        bool keep_im_status;
+
         // ポップアップとカーソルの間のマージン
         int margin_popup;
 
@@ -375,12 +394,18 @@ namespace CONFIG
         // お気に入りの更新チェック時に板の更新もチェックする
         bool check_update_board;
 
+        // 起動時にお気に入りを自動でチェックする
+        bool check_update_boot;
+
         // Ctrl+qでウィンドウを閉じない
         bool disable_close;
 
         // まちBBSの取得に offlaw.cgi を使用する
         bool use_machi_offlaw;
 
+        // 書き込み履歴のあるスレを削除する時にダイアログを表示
+        bool show_del_written_thread_diag;
+
 #ifdef HAVE_MIGEMO_H
         // migemo-dictの場所
         std::string migemodict_path;
