@@ -49,6 +49,10 @@ BoardBase::BoardBase( const std::string& root, const std::string& path_board, co
     : SKELETON::Loadable()
     , m_status( STATUS_UNKNOWN )
     , m_list_subject_created( false )
+    , m_view_sort_column( -1 )
+    , m_view_sort_mode( -1 )
+    , m_view_sort_pre_column( -1 )
+    , m_view_sort_pre_mode( -1 )
     , m_root( root )
     , m_path_board( path_board )
     , m_name( name )
@@ -56,7 +60,9 @@ BoardBase::BoardBase( const std::string& root, const std::string& path_board, co
     , m_live_sec( 0 )
     , m_last_access_time( 0 )
     , m_number_max_res( 0 )
-    , m_rawdata( 0 )
+    , m_iconv( NULL )
+    , m_rawdata( NULL )
+    , m_rawdata_left( NULL )
     , m_read_info( 0 )
     , m_append_articles( false )
     , m_get_article( NULL )
@@ -274,9 +280,19 @@ void BoardBase::clear()
 {
     if( m_rawdata ) free( m_rawdata );
     m_rawdata = NULL;
+
+    if( m_rawdata_left ) free( m_rawdata_left );
+    m_rawdata_left = NULL;
+
     m_lng_rawdata = 0;
+    m_lng_rawdata_left = 0;
 
     m_get_article_url = std::string();
+
+    if( m_iconv ) delete m_iconv;
+    m_iconv = NULL;
+
+    m_list_artinfo.clear();
 }
 
 
@@ -289,6 +305,17 @@ void BoardBase::send_update_board()
     std::cout << "BoardBase::send_update_board\n";
 #endif
 
+    // ダウンロードを開始したビュー以外のビューの内容を更新する
+    //
+    // "update_board" コマンドの後に"update_board_item"を送ると
+    // ローディングが終了しているため行を二回更新してしまうので注意
+    // 詳しくは BoardViewBase::update_item() を参照
+    CORE::core_set_command( "update_board_item", url_subject(),
+                            std::string() // IDとして空文字を送る
+        );
+
+
+    // ダウンロードを開始したビューの内容を更新する
     std::list< std::string >::iterator it = m_url_update_views.begin();
     for( ; it != m_url_update_views.end(); ++it ){
 #ifdef _DEBUG
@@ -498,6 +525,21 @@ const std::string BoardBase::url_dat( const std::string& url, int& num_from, int
     // どちらでもない(スレのURLでない)場合
     else{
 
+        // 過去ログかどうか
+        const std::string pathboard = MISC::replace_str( m_path_board, "?", "\\?" );
+        const std::string query_kako = "^ *(http://.+)" + pathboard  + "/kako(/[1234567890]+)?/[1234567890]+/([1234567890]+).html *$";
+#ifdef _DEBUG
+        std::cout << "query_kako = " << query_kako << std::endl;
+#endif
+        if( regex.exec( query_kako , url ) ){
+
+            std::string url_tmp = regex.str( 1 ) + url_datpath() + regex.str( 3 ) + get_ext();
+#ifdef _DEBUG
+            std::cout << "kako log -> " << url_tmp << std::endl;
+#endif
+            return url_dat( url_tmp, num_from, num_to, num_str );
+        }
+
         // 外部板の移転の場合は path_board も変わるときがあるので
         // 移転した場合はurlを置換してからもう一度試す
         std::string old_root;
@@ -522,6 +564,7 @@ const std::string BoardBase::url_dat( const std::string& url, int& num_from, int
             return url_dat( url_tmp, num_from, num_to, num_str );
         }
 
+
 #ifdef _DEBUG
         std::cout << "not found\n";
 #endif
@@ -853,7 +896,6 @@ void BoardBase::download_subject( const std::string& url_update_view, const bool
     if( read_from_cache && m_list_subject_created ) return;
 
     clear();
-    m_rawdata = ( char* )malloc( SIZE_OF_RAWDATA );
     m_read_url_boardbase = false;
 
     if( read_from_cache ) m_is_online = false;
@@ -896,7 +938,7 @@ void BoardBase::create_loaderdata( JDLIB::LOADERDATA& data )
     data.host_proxy = get_proxy_host();
     data.port_proxy = get_proxy_port();
     data.basicauth_proxy = get_proxy_basicauth();
-    data.size_buf = CONFIG::get_loader_bufsize();
+    data.size_buf = CONFIG::get_loader_bufsize_board();
     data.timeout = CONFIG::get_loader_timeout();
     data.basicauth = get_basicauth();
     data.modified = get_date_modified();
@@ -908,8 +950,45 @@ void BoardBase::create_loaderdata( JDLIB::LOADERDATA& data )
 //
 void BoardBase::receive_data( const char* data, size_t size )
 {
+    if( ! size ) return;
+
+    if( ! m_rawdata ) m_rawdata = ( char* )malloc( SIZE_OF_RAWDATA );
+
     memcpy( m_rawdata + m_lng_rawdata , data, size );
     m_lng_rawdata += size;
+    m_rawdata[ m_lng_rawdata ] = '\0';
+
+    if( m_read_url_boardbase ) return; // url_boardbase をロードして移転が起きたかチェック中
+
+
+    //
+    // 改行ごとに区切ってUTF8に文字コード変換して解析
+    //
+
+    if( ! m_rawdata_left ) m_rawdata_left = ( char* )malloc( SIZE_OF_RAWDATA );
+    if( ! m_iconv ) m_iconv = new JDLIB::Iconv( m_charset, "UTF-8" );
+
+    memcpy( m_rawdata_left + m_lng_rawdata_left, data, size );
+
+    size_t byte_in = size + m_lng_rawdata_left;
+    m_lng_rawdata_left = byte_in;
+    while( byte_in && m_rawdata_left[ byte_in -1 ] != '\n' ) --byte_in;
+    if( byte_in ){
+
+        int byte_out;
+        const char* rawdata_utf8 = m_iconv->convert( m_rawdata_left,  byte_in,  byte_out );
+
+        parse_subject( rawdata_utf8 );
+
+        // 残りを先頭に移動
+        m_lng_rawdata_left -= byte_in;
+        memmove( m_rawdata_left, m_rawdata_left + byte_in, m_lng_rawdata_left );
+
+#ifdef _DEBUG
+        std::cout << "BoardBase::receive_data lng_rawdata = " << m_lng_rawdata << " size = " << size
+                  << " byte_in = " << byte_in << " byte_out = " << byte_out << " lng_rawdata_left = " << m_lng_rawdata_left << std::endl;
+#endif
+    }
 }
 
 
@@ -926,25 +1005,26 @@ void BoardBase::receive_finish()
     m_status &= ~STATUS_UPDATED;
 
     bool read_from_cache = false;
-    std::string path_subject = CACHE::path_board_root_fast( url_boardbase() ) + m_subjecttxt;
-    std::string path_oldsubject = CACHE::path_board_root_fast( url_boardbase() ) + "old-" + m_subjecttxt;
+    const std::string path_subject = CACHE::path_board_root_fast( url_boardbase() ) + m_subjecttxt;
+    const std::string path_oldsubject = CACHE::path_board_root_fast( url_boardbase() ) + "old-" + m_subjecttxt;
 
 #ifdef _DEBUG
     std::cout << "----------------------------------\nBoardBase::receive_finish code = " << get_str_code() << std::endl;
-    std::cout << "size = " << m_lng_rawdata << std::endl;
+    std::cout << "lng_rawdata = " << m_lng_rawdata << std::endl;
 #endif
 
+    ///////////////////////////////////////////////////////
+    //
     // url_boardbase をロードして移転が起きたかチェック
     if( m_read_url_boardbase ){
 
 #ifdef _DEBUG
         std::cout << "move check\n";
 #endif
-        m_rawdata[ m_lng_rawdata ] = '\0';
         set_date_modified( std::string() );
         send_update_board();
 
-        if( get_code() == HTTP_OK && std::string( m_rawdata ).find( "window.location.href" ) != std::string::npos ){
+        if( m_lng_rawdata && get_code() == HTTP_OK && std::string( m_rawdata ).find( "window.location.href" ) != std::string::npos ){
 
 #ifdef _DEBUG
             std::cout << m_rawdata << std::endl;
@@ -990,14 +1070,16 @@ void BoardBase::receive_finish()
         clear();
         return;
     }
+    // 移転チェック終わり
+    // 
+    ///////////////////////////////////////////////////////
+
 
     // サーバーからtimeoutなどのエラーが返った or 移転
     if( get_code() != HTTP_ERR // HTTP_ERR はローダでの内部のエラー
         && get_code() != HTTP_OK
         && get_code() != HTTP_NOT_MODIFIED ){
 
-        m_lng_rawdata = 0;
-
         //
         // リダイレクト(302)の場合は移転確認
         //
@@ -1027,19 +1109,24 @@ void BoardBase::receive_finish()
     // キャッシュから読み込み
     if( read_from_cache ){
 
-        m_lng_rawdata = CACHE::load_rawdata( path_subject, m_rawdata, SIZE_OF_RAWDATA );
-
 #ifdef _DEBUG
         std::cout << "read from cache " << path_subject << std::endl;
 #endif
+        m_lng_rawdata = 0;
+        m_lng_rawdata_left = 0;
+
+        char* rawdata = ( char* )malloc( SIZE_OF_RAWDATA );
+        size_t lng = CACHE::load_rawdata( path_subject, rawdata, SIZE_OF_RAWDATA );
+        receive_data( rawdata, lng );
+        free( rawdata );
     }
 
 #ifdef _DEBUG
-        std::cout << "size(final) = " << m_lng_rawdata << std::endl;
+    std::cout << "size = " << m_list_artinfo.size() << " lng_rawdata = " << m_lng_rawdata << " left = " << m_lng_rawdata_left << std::endl;
 #endif
 
     // データが無い
-    if( m_lng_rawdata == 0 ){
+    if( ! m_list_artinfo.size() ){
 
         set_date_modified( std::string() );
 
@@ -1053,12 +1140,6 @@ void BoardBase::receive_finish()
         return;
     }
 
-    // UTF-8に変換しておく
-    JDLIB::Iconv* libiconv = new JDLIB::Iconv( m_charset, "UTF-8" );
-    int byte_out;
-    const char* rawdata_utf8 = libiconv->convert( m_rawdata , m_lng_rawdata,  byte_out );
-
-
     //////////////////////////////
     // データベース更新
     // subject.txtを解析して現行スレだけsubjectリスト(m_list_subject)に加える
@@ -1067,9 +1148,10 @@ void BoardBase::receive_finish()
     append_all_article_in_cache();
 
     // 一度全てのarticleをdat落ち状態にして subject.txt に
-    // 含まれているものだけ parse_subject()の中で通常状態にする
-    // オフラインの場合は状態を変えない
-    if( m_is_online ){
+    // 含まれているものだけ regist_article()の中で通常状態にする
+    if( m_is_online
+        || SESSION::is_booting() // ブート中の時も状態を変えないと起動直後にスレ一覧を復元した時にdat落ちしたスレが表示されない
+        ){  
 
         ArticleHashIterator it = m_hash_article->begin();
         for( ; it != m_hash_article->end(); ++it ){
@@ -1081,8 +1163,7 @@ void BoardBase::receive_finish()
         }
     }
 
-    // subject.txtをパースしながらデータベース更新
-    parse_subject( rawdata_utf8, m_is_online );
+    regist_article( m_is_online );
 
     // list_subject 更新
     if( ! m_list_subject.empty() ){
@@ -1094,7 +1175,7 @@ void BoardBase::receive_finish()
         if( m_is_online ){
 
             // 既読スレに更新があったかチェック
-            std::list< ArticleBase* >::iterator it_art;
+            std::vector< ArticleBase* >::iterator it_art;
             for( it_art = m_list_subject.begin(); it_art != m_list_subject.end(); ++it_art ){
 
                 if( ( *it_art )->is_cached() && ( *it_art )->get_number() > ( *it_art )->get_number_load() ){
@@ -1108,8 +1189,6 @@ void BoardBase::receive_finish()
         }
 
         // DAT落ちなどでsubject.txtに無いスレもsubjectリストに加える
-        // サブジェクトやロード数などの情報が無いのでスレのinfoファイルから
-        // 取得する必要がある
         if( CONFIG::get_show_oldarticle() ){
 
             ArticleHashIterator it = m_hash_article->begin();
@@ -1119,23 +1198,15 @@ void BoardBase::receive_finish()
                     && ( ( *it )->get_status() & STATUS_OLD )
                     ){
 
-                    // info 読み込み
+
+                    // サブジェクトやロード数などの情報が無いのでスレのinfoファイルから
+                    // 取得する必要がある
                     // TODO : 数が多いとboardビューを開くまで時間がかかるのをなんとかする
 #ifdef _DEBUG
                     std::cout << "read article_info : " << ( *it )->get_url() << std::endl;
 #endif                
                     ( *it )->read_info();
 
-                    // ↑のread_info()で状態が変わる時があるのでDAT落ちに戻してからsubjectリスト(m_list_subject)に加える
-                    int status = ( *it )->get_status();
-
-                    if( status & STATUS_NORMAL ){
-                        status &= ~STATUS_NORMAL;
-                        status |= STATUS_OLD;
-                        ( *it )->set_status( status );
-                        ( *it )->save_info( true );
-                    }
-
                     if( ! is_abone_thread( *it ) ) m_list_subject.push_back( *it );
                 }
             }
@@ -1202,7 +1273,6 @@ void BoardBase::receive_finish()
     // コアにデータベース更新を知らせる
     send_update_board();
 
-    delete libiconv;
     clear();
 }
 
@@ -1222,6 +1292,8 @@ bool BoardBase::start_checkking_if_board_moved()
     std::cout << "BoardBase::start_checkking_if_board_moved " << url_boardbase() << std::endl;
 #endif
 
+    m_lng_rawdata = 0;
+
     JDLIB::LOADERDATA data;
     data.init_for_data();
     data.url = url_boardbase();
@@ -1578,37 +1650,51 @@ void BoardBase::set_local_proxy_w( const std::string& proxy )
 //
 // キャッシュ内のログ検索
 //
-// datファイルのURL(read.cgi型)を返す
+// ArticleBase のアドレスをリスト(list_article)にセットして返す
+// query が空の時はキャッシュにあるログを全てヒットさせる
+// 
 //
-std::list< std::string > BoardBase::search_cache( const std::string& query,
-                                                  bool mode_or, // 今のところ無視
-                                                  bool& stop // 呼出元のスレッドで true にセットすると検索を停止する
+void BoardBase::search_cache( std::vector< DBTREE::ArticleBase* >& list_article,
+                              const std::string& query,
+                              const bool mode_or, // 今のところ無視
+                              const bool& stop // 呼出元のスレッドで true にセットすると検索を停止する
     )
 {
 #ifdef _DEBUG
     std::cout << "BoardBase::search_cache " << query << std::endl;
 #endif
 
-    std::list< std::string >list_out;
-
-    if( empty() ) return list_out;
+    if( empty() ) return;
 
     // キャッシュにあるレスをデータベースに登録
     append_all_article_in_cache();
-    if( m_hash_article->size() == 0 ) return list_out;
+    if( m_hash_article->size() == 0 ) return;
 
-    std::string query_local = MISC::Iconv( query, "UTF-8", get_charset() );
-    std::list< std::string > list_query = MISC::split_line( query_local );
+    const bool append_all = query.empty();
+    const std::string query_local = MISC::Iconv( query, "UTF-8", get_charset() );
+    const std::list< std::string > list_query = MISC::split_line( query_local );
 
-    std::string path_board_root = CACHE::path_board_root_fast( url_boardbase() );
+    const std::string path_board_root = CACHE::path_board_root_fast( url_boardbase() );
 
     ArticleHashIterator it = m_hash_article->begin();
     for( ; it != m_hash_article->end(); ++it ){
 
+        if( stop ) break;
+
         ArticleBase* article = ( *it );
         if( ! article->is_cached() ) continue;
 
-        std::string path = path_board_root + article->get_id();
+        if( append_all ){
+
+#ifdef _DEBUG
+            std::cout << "append " << article->get_subject() << std::endl;
+#endif
+            article->read_info();
+            list_article.push_back( article );
+            continue;
+        }
+
+        const std::string path = path_board_root + article->get_id();
         std::string rawdata;
 
         if( CACHE::load_rawdata( path, rawdata ) > 0 ){
@@ -1619,7 +1705,7 @@ std::list< std::string > BoardBase::search_cache( const std::string& query,
             std::cout << "load " << path << " size = " << rawdata.size() << " byte" << std::endl;
 #endif
 
-            std::list< std::string >::iterator it_query = list_query.begin();
+            std::list< std::string >::const_iterator it_query = list_query.begin();
             for( ; it_query != list_query.end(); ++it_query ){
 
                 if( rawdata.find( *it_query ) == std::string::npos ){
@@ -1633,15 +1719,11 @@ std::list< std::string > BoardBase::search_cache( const std::string& query,
                 std::cout << "found word in " << url_readcgi( article->get_url(), 0, 0 ) << std::endl
                           << article->get_subject() << std::endl;
 #endif
-                std::string readcgi = url_readcgi( article->get_url(), 0, 0 );
-                list_out.push_back( readcgi );
+                article->read_info();
+                list_article.push_back( article );
             }
         }
-
-        if( stop ) break;
     }
-
-    return list_out;
 }
 
 
@@ -1894,7 +1976,7 @@ void BoardBase::save_summary()
     std::ostringstream sstr_out;
     sstr_out << "(";
 
-    std::list< ArticleBase* >::iterator it;
+    std::vector< ArticleBase* >::iterator it;
     for( it = m_list_subject.begin(); it != m_list_subject.end(); ++it ){
 
         ArticleBase* art = *( it );
