@@ -47,6 +47,18 @@
 using namespace CORE;
 
 
+
+//
+// URLを開く
+//
+void Core::slot_openurl()
+{
+    SKELETON::PrefDiag* pref= CORE::PrefDiagFactory( NULL, CORE::PREFDIAG_OPENURL, "" );
+    pref->run();
+    delete pref;
+}
+
+
 //
 // オンライン、オフライン切替え
 //
@@ -162,10 +174,42 @@ void Core::slot_quit()
 }
 
 
+//
+// スレ一覧のsinceの表示モード
+void Core::slot_toggle_since( const int mode )
+{
+    if( ! m_enable_menuslot ) return;
+    if( SESSION::get_col_since_time() == mode ) return;
+
+#ifdef _DEBUG
+    std::cout << "Core::slot_toggle_since mode = " << mode << std::endl;
+#endif
+
+    SESSION::set_col_since_time( mode );
+    BOARD::get_admin()->set_command( "relayout_all" );    
+}
+
+
+//
+// スレ一覧の最終書込の表示モード
+void Core::slot_toggle_write( const int mode )
+{
+    if( ! m_enable_menuslot ) return;
+    if( SESSION::get_col_write_time() == mode ) return;
+
+#ifdef _DEBUG
+    std::cout << "Core::slot_toggle_write mode = " << mode << std::endl;
+#endif
+
+    SESSION::set_col_write_time( mode );
+    BOARD::get_admin()->set_command( "relayout_all" );    
+}
+
+
 //
 // ツールバーの表示モード
 //
-void Core::slot_toggle_toolbarpos( int pos )
+void Core::slot_toggle_toolbarpos( const int pos )
 {
     if( SESSION::is_booting() ) return;
     if( ! m_enable_menuslot ) return;
@@ -177,8 +221,8 @@ void Core::slot_toggle_toolbarpos( int pos )
     pack_widget( true );
 
     // 表示切り替え
-    if( SESSION::toolbar_pos() == pos ) pos = SESSION::TOOLBAR_POS_NOT;
-    SESSION::set_toolbar_pos( pos );
+    if( SESSION::toolbar_pos() == pos ) SESSION::set_toolbar_pos( SESSION::TOOLBAR_POS_NOT ); // 隠す
+    else SESSION::set_toolbar_pos( pos );
 
     pack_widget( false );
 
@@ -388,9 +432,9 @@ void Core::slot_toggle_show_ssspicon()
 //
 // リスト項目(スレ一覧)の設定
 //
-void Core::slot_setup_boarditemcolumn()
+void Core::slot_setup_boarditem_column()
 {
-    SKELETON::PrefDiag* pref= CORE::PrefDiagFactory( NULL, CORE::PREFDIAG_BOARDITEMCOLUM, "" );
+    SKELETON::PrefDiag* pref= CORE::PrefDiagFactory( NULL, CORE::PREFDIAG_BOARDITEM_COLUM, "" );
     pref->run();
     delete pref;
 }
@@ -451,6 +495,17 @@ void Core::slot_setup_msgitem()
 }
 
 
+//
+// コンテキストメニュー(スレビュー)の表示項目
+//
+void Core::slot_setup_articleitem_menu()
+{
+    SKELETON::PrefDiag* pref= CORE::PrefDiagFactory( NULL, CORE::PREFDIAG_ARTICLEITEM_MENU, "" );
+    pref->run();
+    delete pref;
+}
+
+
 //
 // スレ一覧のプロパティ
 //
@@ -642,6 +697,7 @@ void Core::slot_changefont_main()
     Gtk::FontSelectionDialog diag;
     diag.set_font_name( CONFIG::get_fontname( FONT_MAIN ) );
     diag.set_title( "スレビューフォント" );
+    diag.set_transient_for( *CORE::get_mainwindow() );
     if( diag.run() == Gtk::RESPONSE_OK ){
 
         CONFIG::set_fontname( FONT_MAIN, diag.get_font_name() );
@@ -662,6 +718,7 @@ void Core::slot_changefont_popup()
     Gtk::FontSelectionDialog diag;
     diag.set_font_name( CONFIG::get_fontname( FONT_POPUP ) );
     diag.set_title( "ポップアップフォント" );
+    diag.set_transient_for( *CORE::get_mainwindow() );
     if( diag.run() == Gtk::RESPONSE_OK ){
 
         CONFIG::set_fontname( FONT_POPUP, diag.get_font_name() );
@@ -678,6 +735,7 @@ void Core::slot_changefont_tree()
     Gtk::FontSelectionDialog diag;
     diag.set_font_name( CONFIG::get_fontname( FONT_BBS ) );
     diag.set_title( "板／スレ一覧フォント" );
+    diag.set_transient_for( *CORE::get_mainwindow() );
     if( diag.run() == Gtk::RESPONSE_OK ){
 
         CONFIG::set_fontname( FONT_BBS, diag.get_font_name() );
@@ -974,6 +1032,25 @@ void Core::slot_search_cache()
 }
 
 
+//
+// 現在開いている板のキャッシュ内のログ一覧表示
+//
+void Core::slot_show_cache_board()
+{
+    std::string url = DBTREE::url_subject( BOARD::get_admin()->get_current_url() );
+    if( ! url.empty() ) CORE::core_set_command( "open_board_showlog", url );
+}
+
+
+//
+// キャッシュ内の全ログ一覧表示
+//
+void Core::slot_show_cache()
+{
+    CORE::core_set_command( "open_board_showalllog" );
+}
+
+
 //
 // スレタイ検索
 //
@@ -984,7 +1061,7 @@ void Core::slot_search_title()
 
 
 //
-// お気に入りルートからの更新チェック( 通常 )
+// サイドバーの全更新チェック
 //
 void Core::slot_check_update_root()
 {
@@ -993,7 +1070,7 @@ void Core::slot_check_update_root()
 
 
 //
-// お気に入りルートからの更新チェック( タブで開く )
+// サイドバーを全更新チェックしてタブで開く
 //
 void Core::slot_check_update_open_root()
 {
