@@ -51,6 +51,8 @@ DragableNoteBook::DragableNoteBook()
     m_show_tabs = true;
     m_show_toolbar = true;
 
+    memset( &m_alloc_old, 0, sizeof( Alloc_NoteBook ) );
+
     show_all_children();
 }
 
@@ -152,7 +154,7 @@ const Alloc_NoteBook DragableNoteBook::get_alloc_notebook()
     alloc.y_toolbar = m_notebook_toolbar.get_allocation().get_y();
     alloc.height_toolbar = m_notebook_toolbar.get_allocation().get_height();
 
-    const int offset_tabbar = ( get_show_tabs() ? alloc.height_tabbar - alloc.height_tab : 0 );
+    const int offset_tabbar = ( get_show_tabs() ? alloc.height_tabbar - ( alloc.y_tab + alloc.height_tab ) : 0 );
     alloc.x_box = m_notebook_view.get_allocation().get_x();
     alloc.y_box = m_notebook_view.get_allocation().get_y() - alloc.height_toolbar - offset_tabbar;
     alloc.width_box =m_notebook_view.get_allocation().get_width();
@@ -187,12 +189,23 @@ void DragableNoteBook::draw_box( Gtk::Widget* widget, GdkEventExpose* event )
 {
     const Glib::RefPtr<Gdk::Window> win = widget->get_window();
     const Gdk::Rectangle rect( &(event->area) );
-    const Alloc_NoteBook alloc = get_alloc_notebook();
+    Alloc_NoteBook alloc = get_alloc_notebook();
 
     if( alloc.height_box > 0 ){
 
         if( get_show_tabs() ){
 
+            // gtk2.18以降？では新しいタブを開くときに一瞬タブが消える場合がある
+            // その場合は保存しておいた座標と高さを利用してboxを描画する
+            if( ! alloc.height_tab ){
+
+                if( ! m_alloc_old.height_tab ) return;
+
+                alloc.y_box = m_alloc_old.y_box;
+                alloc.height_box = m_alloc_old.height_box;
+            }
+            else m_alloc_old = alloc;
+
             widget->get_style()->paint_box_gap( win,
                                                 Gtk::STATE_NORMAL,
                                                 Gtk::SHADOW_OUT,
