@@ -5,6 +5,7 @@
 
 #include <gtkmm.h>
 #include <string>
+#include <set>
 
 #include "control/control.h"
 
@@ -26,6 +27,7 @@ namespace SKELETON
         SIG_RESIZE_POPUP m_sig_resize_popup;
 
         std::string m_url;
+        Gtk::Window* m_parent_win;
 
         // クライアント領域の幅、高さ
         int m_width_client;
@@ -37,6 +39,7 @@ namespace SKELETON
         // ポップアップメニュー
         Glib::RefPtr< Gtk::ActionGroup > m_action_group;
         Glib::RefPtr< Gtk::UIManager > m_ui_manager;
+        std::set< std::string > m_url_popup;
 
         // ツールバーに表示する文字列
         std::string m_label;
@@ -66,12 +69,18 @@ namespace SKELETON
         // ロック状態
         bool m_locked;
 
+        // 書き込み可能か
+        bool m_writeable;
+
         // ツールバーのID
         int m_id_toolbar;
 
         // 検索文字列
         std::string m_search_query;
 
+        // ポップアップ時に全ての領域を表示できないならカーソルの上に表示
+        bool m_popup_upside;
+
       protected:
 
         void set_url( const std::string& url_new, const bool update_history );
@@ -133,6 +142,9 @@ namespace SKELETON
         // ポップアップメニュー表示時に表示位置を決めるスロット
         void slot_popup_menu_position( int& x, int& y, bool& push_in );
 
+        // ポップアップメニューがmapした時に呼び出されるスロット
+        void slot_map_popupmenu();
+
         // ポップアップメニューがhideした時に呼び出されるスロット
         void slot_hide_popupmenu();
 
@@ -152,8 +164,11 @@ namespace SKELETON
 
         virtual const std::string& get_url(){ return m_url; }
 
+        virtual void set_parent_win( Gtk::Window* parent_win ){ m_parent_win = parent_win; }
+        virtual Gtk::Window* get_parent_win(){ return m_parent_win; }
+
         // 移転があったときなどにadminから呼び出される
-        void update_url( const std::string& url_old, const std::string& url_new );
+        virtual void update_url( const std::string& url_old, const std::string& url_new );
 
         // 検索文字列
         const std::string& get_search_query(){ return m_search_query; }
@@ -171,8 +186,16 @@ namespace SKELETON
         virtual void lock(){ m_locked = true; }
         virtual void unlock(){ m_locked = false; }
 
+        // 書き込み可能/不可能
+        const bool is_writeable() const { return m_writeable; }
+        void set_writeable( const bool writeable ){ m_writeable = writeable; }
+
+        // ポップアップ時に全ての領域を表示できないならカーソルの上に表示
+        const bool get_popup_upside() const { return m_popup_upside; }
+        void set_popup_upside( const bool upside ){ m_popup_upside = upside; }
+
         // view 上にマウスポインタがあれば true
-        bool is_mouse_on_view();
+        const bool is_mouse_on_view();
 
         // 各view個別のコマンド
         virtual const bool set_command( const std::string& command,
@@ -228,6 +251,9 @@ namespace SKELETON
         // shutdown( SIGHUP )用
         virtual void shutdown(){}
 
+        // キーを押した
+        virtual const bool slot_key_press( GdkEventKey* event ){ return false; }
+
         // クロック入力
         // clock_in()はビューがアクティブのときに呼び出される
         // clock_in_always()はviewの種類に依らず常に呼び出されるので重い処理を含めてはいけない
@@ -252,7 +278,7 @@ namespace SKELETON
         virtual const bool operate_view( const int ) = 0;
         virtual void goto_top(){}
         virtual void goto_bottom(){}
-        virtual void goto_num( int num ){}
+        virtual void goto_num( const int num_to, const int num_from ){}
         virtual void scroll_up(){}
         virtual void scroll_down(){}
         virtual void scroll_left(){}
